@@ -10,15 +10,18 @@ from .amount import Amount
 
 
 __author__ = 'Qingxu Kuang<kuangqingxu@transfereasy.com>'
-__version__ = '1.0.9'
+__version__ = '1.1.0'
 
 
 class Money(object):
 
-    def __init__(self, *, currency, amount):
+    def __init__(self, *, currency, amount, origin=False):
 
         self._currency = currency
-        self._amount = Amount(amount)
+        self._amount = Amount(
+            amount,
+            currency.accuracy if not origin else 1
+        )
 
     @property
     def currency(self):
@@ -46,31 +49,40 @@ class Money(object):
 
         return self.__class__(
             currency=self._currency,
-            amount=self._amount.value + other.amount.value
+            amount=self._amount.value + other.amount.value,
+            origin=True
         )
 
     def __radd__(self, other):
+
         return self.__add__(other)
 
     def __sub__(self, other):
+
         return self.__add__(-other)
 
     def __rsub__(self, other):
+
         return other - self
 
     def __abs__(self):
+
         return self.__class__(
             currency=self._currency,
-            amount=abs(self._amount.value)
+            amount=abs(self._amount.value),
+            origin=True
         )
 
     def __neg__(self):
+
         return self.__class__(
             currency=self._currency,
-            amount=-self._amount.value
+            amount=-self._amount.value,
+            origin=True
         )
 
     def __eq__(self, other):
+
         if isinstance(other, Money):
             return (
                 self._currency == other.currency
@@ -80,9 +92,11 @@ class Money(object):
         return False
 
     def __ne__(self, other):
+
         return not self.__eq__(other)
 
     def __gt__(self, other):
+
         if not isinstance(other, Money):
             raise TypeError(
                 'Money instance cannot be compared with non-Money instance.'
@@ -95,6 +109,7 @@ class Money(object):
             )
 
     def __lt__(self, other):
+
         if not isinstance(other, Money):
             raise TypeError(
                 'Money instance cannot be compared with non-Money instance.'
@@ -107,9 +122,11 @@ class Money(object):
             )
 
     def __ge__(self, other):
+
         return (self == other) or (self > other)
 
     def __le__(self, other):
+
         return (self == other) or (self < other)
 
     def exchange(self, forex_rate):
@@ -119,7 +136,7 @@ class Money(object):
                 f'{self.currency.iso_code} Not Equals {forex_rate.base_currency.iso_code}'
             )
 
-        amount = self.amount.exchange(forex_rate)
+        amount = self.amount.exchange(forex_rate) / forex_rate.target_currency.accuracy
 
         return Money(
             currency=forex_rate.target_currency,
