@@ -29,6 +29,11 @@ class Currency(object):
     def __ne__(self, other):
         return not self.__eq__(other)
 
+    def __hash__(self):
+        return hash(
+            (self._iso_code, self._numric_code, self._accuracy)
+        )
+
     @property
     def iso_code(self):
         return self._iso_code
