@@ -9,10 +9,9 @@ from decimal import (
 class FeeRate(object):
 
     def __init__(self, rate):
-# 费率 = 原费率 * 10的8次方
-        self.weight = Decimal(pow(10, 8))
-        # 精度，保持小数点后0位
-        self.accuracy = Decimal('1')
+
+        self.weight = Decimal('1')
+        self.accuracy = Decimal('0.00000001')
 
         self.rate = (Decimal(rate) * self.weight).quantize(
             self.accuracy,
