@@ -8,12 +8,10 @@ from decimal import (
 
 class ForexRate(object):
 
-    def __init__(self, base_currency, target_currency, rate, origin=False):
+    def __init__(self, base_currency, target_currency, rate):
 
-        # 汇率 = 原汇率 * 10的8次方
-        self.weight = Decimal('1') if origin else Decimal(pow(10, 8))
-        # 精度，保持小数点后0位
-        self.accuracy = Decimal('1')
+        self.weight = Decimal('1')
+        self.accuracy = Decimal('0.00000001')
 
         self.rate = (Decimal(rate) * self.weight).quantize(
             self.accuracy,
