@@ -18,6 +18,11 @@ def test_forex_rate():
         numric_code='998',
         accuracy=100
     )
+    jpy_currency = Currency(
+        iso_code='JPY',
+        numric_code='997',
+        accuracy=1
+    )
     f1 = ForexRate(
         base_currency,
         target_currency,
@@ -26,20 +31,27 @@ def test_forex_rate():
 
     f2 = f1.reverse()
 
-    assert f1.rate == Decimal('91200000'), 'Error'
-    assert f2.rate == Decimal('109649123'), 'Error'
+    f4 = ForexRate(
+        target_currency,
+        jpy_currency,
+        '15.0932'
+    )
+
+    f5 = f4.reverse()
+
+    assert f1.rate == Decimal('0.912'), 'Error'
+    assert f2.rate == Decimal('1.09649123'), 'Error'
 
     f3 = ForexRate(
         base_currency,
         target_currency,
-        '912',
-        True
+        '0.912',
     )
 
-    assert f3.rate == Decimal('912'), 'Error'
+    assert f3.rate == Decimal('0.912'), 'Error'
 
     m1 = Money(
-        amount=320,
+        amount=3.20,
         currency=base_currency
     )
 
@@ -49,3 +61,15 @@ def test_forex_rate():
 
     assert m2.amount == '291', 'Error'
     assert m3.amount == '319', 'Error'
+
+    m_jpy = Money(
+        amount=100,
+        currency=jpy_currency
+    )
+
+    m_cny = m_jpy.exchange(f5)
+
+    m_jpy_2 = m_cny.exchange(f4)
+
+    assert m_cny.amount == '662', 'Error'
+    assert m_jpy_2.amount == '99', 'Error'
